# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import joint_pb2 as joint__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kinematics.proto',
  package='reachy.sdk.kinematics',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x0bjoint.proto\"J\n\rJointPosition\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12\x11\n\tpositions\x18\x02 \x03(\x01\"\x19\n\tMatrix4x4\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"8\n\nQuaternion\x12\t\n\x01w\x18\x01 \x01(\x01\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\t\n\x01z\x18\x04 \x01(\x01\x62\x06proto3'
  ,
  dependencies=[joint__pb2.DESCRIPTOR,])




_JOINTPOSITION = _descriptor.Descriptor(
  name='JointPosition',
  full_name='reachy.sdk.kinematics.JointPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.kinematics.JointPosition.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='reachy.sdk.kinematics.JointPosition.positions', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=130,
)


_MATRIX4X4 = _descriptor.Descriptor(
  name='Matrix4x4',
  full_name='reachy.sdk.kinematics.Matrix4x4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='reachy.sdk.kinematics.Matrix4x4.data', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=157,
)


_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='reachy.sdk.kinematics.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='w', full_name='reachy.sdk.kinematics.Quaternion.w', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='reachy.sdk.kinematics.Quaternion.x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='reachy.sdk.kinematics.Quaternion.y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='reachy.sdk.kinematics.Quaternion.z', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=215,
)

_JOINTPOSITION.fields_by_name['ids'].message_type = joint__pb2._JOINTID
DESCRIPTOR.message_types_by_name['JointPosition'] = _JOINTPOSITION
DESCRIPTOR.message_types_by_name['Matrix4x4'] = _MATRIX4X4
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JointPosition = _reflection.GeneratedProtocolMessageType('JointPosition', (_message.Message,), {
  'DESCRIPTOR' : _JOINTPOSITION,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.JointPosition)
  })
_sym_db.RegisterMessage(JointPosition)

Matrix4x4 = _reflection.GeneratedProtocolMessageType('Matrix4x4', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX4X4,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.Matrix4x4)
  })
_sym_db.RegisterMessage(Matrix4x4)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orbita_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='orbita_kinematics.proto',
  package='reachy.sdk.kinematics',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17orbita_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"?\n\x0fOrbitaIKRequest\x12,\n\x01q\x18\x01 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternion\"-\n\nLookVector\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"`\n\x10OrbitaIKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12;\n\rdisk_position\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition2\xd6\x01\n\x10OrbitaKinematics\x12\x62\n\x0f\x43omputeOrbitaIK\x12&.reachy.sdk.kinematics.OrbitaIKRequest\x1a\'.reachy.sdk.kinematics.OrbitaIKSolution\x12^\n\x16GetQuaternionTransform\x12!.reachy.sdk.kinematics.LookVector\x1a!.reachy.sdk.kinematics.Quaternionb\x06proto3'
  ,
  dependencies=[kinematics__pb2.DESCRIPTOR,])




_ORBITAIKREQUEST = _descriptor.Descriptor(
  name='OrbitaIKRequest',
  full_name='reachy.sdk.kinematics.OrbitaIKRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='q', full_name='reachy.sdk.kinematics.OrbitaIKRequest.q', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=131,
)


_LOOKVECTOR = _descriptor.Descriptor(
  name='LookVector',
  full_name='reachy.sdk.kinematics.LookVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='reachy.sdk.kinematics.LookVector.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='reachy.sdk.kinematics.LookVector.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='reachy.sdk.kinematics.LookVector.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=178,
)


_ORBITAIKSOLUTION = _descriptor.Descriptor(
  name='OrbitaIKSolution',
  full_name='reachy.sdk.kinematics.OrbitaIKSolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.kinematics.OrbitaIKSolution.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_position', full_name='reachy.sdk.kinematics.OrbitaIKSolution.disk_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=276,
)

_ORBITAIKREQUEST.fields_by_name['q'].message_type = kinematics__pb2._QUATERNION
_ORBITAIKSOLUTION.fields_by_name['disk_position'].message_type = kinematics__pb2._JOINTPOSITION
DESCRIPTOR.message_types_by_name['OrbitaIKRequest'] = _ORBITAIKREQUEST
DESCRIPTOR.message_types_by_name['LookVector'] = _LOOKVECTOR
DESCRIPTOR.message_types_by_name['OrbitaIKSolution'] = _ORBITAIKSOLUTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrbitaIKRequest = _reflection.GeneratedProtocolMessageType('OrbitaIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORBITAIKREQUEST,
  '__module__' : 'orbita_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.OrbitaIKRequest)
  })
_sym_db.RegisterMessage(OrbitaIKRequest)

LookVector = _reflection.GeneratedProtocolMessageType('LookVector', (_message.Message,), {
  'DESCRIPTOR' : _LOOKVECTOR,
  '__module__' : 'orbita_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.LookVector)
  })
_sym_db.RegisterMessage(LookVector)

OrbitaIKSolution = _reflection.GeneratedProtocolMessageType('OrbitaIKSolution', (_message.Message,), {
  'DESCRIPTOR' : _ORBITAIKSOLUTION,
  '__module__' : 'orbita_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.OrbitaIKSolution)
  })
_sym_db.RegisterMessage(OrbitaIKSolution)



_ORBITAKINEMATICS = _descriptor.ServiceDescriptor(
  name='OrbitaKinematics',
  full_name='reachy.sdk.kinematics.OrbitaKinematics',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=279,
  serialized_end=493,
  methods=[
  _descriptor.MethodDescriptor(
    name='ComputeOrbitaIK',
    full_name='reachy.sdk.kinematics.OrbitaKinematics.ComputeOrbitaIK',
    index=0,
    containing_service=None,
    input_type=_ORBITAIKREQUEST,
    output_type=_ORBITAIKSOLUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetQuaternionTransform',
    full_name='reachy.sdk.kinematics.OrbitaKinematics.GetQuaternionTransform',
    index=1,
    containing_service=None,
    input_type=_LOOKVECTOR,
    output_type=kinematics__pb2._QUATERNION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORBITAKINEMATICS)

DESCRIPTOR.services_by_name['OrbitaKinematics'] = _ORBITAKINEMATICS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fan.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fan.proto',
  package='reachy.sdk.fan',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tfan.proto\x12\x0ereachy.sdk.fan\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\",\n\x05\x46\x61nId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"%\n\x06\x46\x61nsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"e\n\x10\x46\x61nsStateRequest\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x16\n\x08\x46\x61nState\x12\n\n\x02on\x18\x01 \x01(\x08\"\x88\x01\n\tFansState\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12(\n\x06states\x18\x02 \x03(\x0b\x32\x18.reachy.sdk.fan.FanState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\";\n\nFanCommand\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.reachy.sdk.fan.FanId\x12\n\n\x02on\x18\x02 \x01(\x08\"j\n\x0b\x46\x61nsCommand\x12,\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.fan.FanCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x0e\x46\x61nsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x01\n\x14\x46\x61nControllerService\x12>\n\x0cGetAllFansId\x12\x16.google.protobuf.Empty\x1a\x16.reachy.sdk.fan.FansId\x12K\n\x0cGetFansState\x12 .reachy.sdk.fan.FansStateRequest\x1a\x19.reachy.sdk.fan.FansState\x12O\n\x10SendFansCommands\x12\x1b.reachy.sdk.fan.FansCommand\x1a\x1e.reachy.sdk.fan.FansCommandAckb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_FANID = _descriptor.Descriptor(
  name='FanId',
  full_name='reachy.sdk.fan.FanId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='reachy.sdk.fan.FanId.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='reachy.sdk.fan.FanId.uid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='reachy.sdk.fan.FanId.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=91,
  serialized_end=135,
)


_FANSID = _descriptor.Descriptor(
  name='FansId',
  full_name='reachy.sdk.fan.FansId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='reachy.sdk.fan.FansId.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uids', full_name='reachy.sdk.fan.FansId.uids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=174,
)


_FANSSTATEREQUEST = _descriptor.Descriptor(
  name='FansStateRequest',
  full_name='reachy.sdk.fan.FansStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.fan.FansStateRequest.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.fan.FansStateRequest.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=277,
)


_FANSTATE = _descriptor.Descriptor(
  name='FanState',
  full_name='reachy.sdk.fan.FanState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='on', full_name='reachy.sdk.fan.FanState.on', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=301,
)


_FANSSTATE = _descriptor.Descriptor(
  name='FansState',
  full_name='reachy.sdk.fan.FansState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.fan.FansState.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='reachy.sdk.fan.FansState.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.fan.FansState.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=440,
)


_FANCOMMAND = _descriptor.Descriptor(
  name='FanCommand',
  full_name='reachy.sdk.fan.FanCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='reachy.sdk.fan.FanCommand.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on', full_name='reachy.sdk.fan.FanCommand.on', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=501,
)


_FANSCOMMAND = _descriptor.Descriptor(
  name='FansCommand',
  full_name='reachy.sdk.fan.FansCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='reachy.sdk.fan.FansCommand.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.fan.FansCommand.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=609,
)


_FANSCOMMANDACK = _descriptor.Descriptor(
  name='FansCommandAck',
  full_name='reachy.sdk.fan.FansCommandAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.fan.FansCommandAck.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=644,
)

_FANID.oneofs_by_name['id'].fields.append(
  _FANID.fields_by_name['name'])
_FANID.fields_by_name['name'].containing_oneof = _FANID.oneofs_by_name['id']
_FANID.oneofs_by_name['id'].fields.append(
  _FANID.fields_by_name['uid'])
_FANID.fields_by_name['uid'].containing_oneof = _FANID.oneofs_by_name['id']
_FANSSTATEREQUEST.fields_by_name['ids'].message_type = _FANID
_FANSSTATEREQUEST.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FANSSTATE.fields_by_name['ids'].message_type = _FANID
_FANSSTATE.fields_by_name['states'].message_type = _FANSTATE
_FANSSTATE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FANCOMMAND.fields_by_name['id'].message_type = _FANID
_FANSCOMMAND.fields_by_name['commands'].message_type = _FANCOMMAND
_FANSCOMMAND.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['FanId'] = _FANID
DESCRIPTOR.message_types_by_name['FansId'] = _FANSID
DESCRIPTOR.message_types_by_name['FansStateRequest'] = _FANSSTATEREQUEST
DESCRIPTOR.message_types_by_name['FanState'] = _FANSTATE
DESCRIPTOR.message_types_by_name['FansState'] = _FANSSTATE
DESCRIPTOR.message_types_by_name['FanCommand'] = _FANCOMMAND
DESCRIPTOR.message_types_by_name['FansCommand'] = _FANSCOMMAND
DESCRIPTOR.message_types_by_name['FansCommandAck'] = _FANSCOMMANDACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FanId = _reflection.GeneratedProtocolMessageType('FanId', (_message.Message,), {
  'DESCRIPTOR' : _FANID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanId)
  })
_sym_db.RegisterMessage(FanId)

FansId = _reflection.GeneratedProtocolMessageType('FansId', (_message.Message,), {
  'DESCRIPTOR' : _FANSID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansId)
  })
_sym_db.RegisterMessage(FansId)

FansStateRequest = _reflection.GeneratedProtocolMessageType('FansStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATEREQUEST,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansStateRequest)
  })
_sym_db.RegisterMessage(FansStateRequest)

FanState = _reflection.GeneratedProtocolMessageType('FanState', (_message.Message,), {
  'DESCRIPTOR' : _FANSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanState)
  })
_sym_db.RegisterMessage(FanState)

FansState = _reflection.GeneratedProtocolMessageType('FansState', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansState)
  })
_sym_db.RegisterMessage(FansState)

FanCommand = _reflection.GeneratedProtocolMessageType('FanCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanCommand)
  })
_sym_db.RegisterMessage(FanCommand)

FansCommand = _reflection.GeneratedProtocolMessageType('FansCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommand)
  })
_sym_db.RegisterMessage(FansCommand)

FansCommandAck = _reflection.GeneratedProtocolMessageType('FansCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMANDACK,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommandAck)
  })
_sym_db.RegisterMessage(FansCommandAck)



_FANCONTROLLERSERVICE = _descriptor.ServiceDescriptor(
  name='FanControllerService',
  full_name='reachy.sdk.fan.FanControllerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=647,
  serialized_end=891,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAllFansId',
    full_name='reachy.sdk.fan.FanControllerService.GetAllFansId',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_FANSID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFansState',
    full_name='reachy.sdk.fan.FanControllerService.GetFansState',
    index=1,
    containing_service=None,
    input_type=_FANSSTATEREQUEST,
    output_type=_FANSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFansCommands',
    full_name='reachy.sdk.fan.FanControllerService.SendFansCommands',
    index=2,
    containing_service=None,
    input_type=_FANSCOMMAND,
    output_type=_FANSCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FANCONTROLLERSERVICE)

DESCRIPTOR.services_by_name['FanControllerService'] = _FANCONTROLLERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: joint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='joint.proto',
  package='reachy.sdk.joint',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bjoint.proto\x12\x10reachy.sdk.joint\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"+\n\x08PIDGains\x12\t\n\x01p\x18\x01 \x01(\x02\x12\t\n\x01i\x18\x02 \x01(\x02\x12\t\n\x01\x64\x18\x03 \x01(\x02\"\x8f\x01\n\x15\x43omplianceMarginSlope\x12\x1c\n\x14\x63w_compliance_margin\x18\x01 \x01(\x02\x12\x1d\n\x15\x63\x63w_compliance_margin\x18\x02 \x01(\x02\x12\x1b\n\x13\x63w_compliance_slope\x18\x03 \x01(\x02\x12\x1c\n\x14\x63\x63w_compliance_slope\x18\x04 \x01(\x02\"}\n\x08PIDValue\x12)\n\x03pid\x18\x01 \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDGainsH\x00\x12=\n\ncompliance\x18\x02 \x01(\x0b\x32\'.reachy.sdk.joint.ComplianceMarginSlopeH\x00\x42\x07\n\x05gains\".\n\x07JointId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"\x86\x04\n\nJointState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x03uid\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x10present_position\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\rpresent_speed\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0cpresent_load\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0btemperature\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\tcompliant\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rgoal_position\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bspeed_limit\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0ctorque_limit\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x03pid\x18\x0b \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDValue\"\x92\x01\n\x0bJointsState\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12,\n\x06states\x18\x02 \x03(\x0b\x32\x1c.reachy.sdk.joint.JointState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\x08JointsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"\xa3\x01\n\x12JointsStateRequest\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12\x36\n\x10requested_fields\x18\x02 \x03(\x0e\x32\x1c.reachy.sdk.joint.JointField\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x96\x01\n\x13StreamJointsRequest\x12\x35\n\x07request\x18\x01 \x01(\x0b\x32$.reachy.sdk.joint.JointsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa6\x02\n\x0cJointCommand\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.joint.JointId\x12-\n\tcompliant\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rgoal_position\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bspeed_limit\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0ctorque_limit\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x03pid\x18\x0b \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDValue\"p\n\rJointsCommand\x12\x30\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1e.reachy.sdk.joint.JointCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x10JointsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08*\xcc\x01\n\nJointField\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x07\n\x03UID\x10\x02\x12\x14\n\x10PRESENT_POSITION\x10\x03\x12\x11\n\rPRESENT_SPEED\x10\x04\x12\x10\n\x0cPRESENT_LOAD\x10\x05\x12\x0f\n\x0bTEMPERATURE\x10\x06\x12\r\n\tCOMPLIANT\x10\x07\x12\x11\n\rGOAL_POSITION\x10\x08\x12\x0f\n\x0bSPEED_LIMIT\x10\t\x12\x10\n\x0cTORQUE_LIMIT\x10\n\x12\x07\n\x03PID\x10\x0b\x12\x07\n\x03\x41LL\x10\x0f\x32\xc2\x03\n\x0cJointService\x12\x44\n\x0eGetAllJointsId\x12\x16.google.protobuf.Empty\x1a\x1a.reachy.sdk.joint.JointsId\x12U\n\x0eGetJointsState\x12$.reachy.sdk.joint.JointsStateRequest\x1a\x1d.reachy.sdk.joint.JointsState\x12[\n\x11StreamJointsState\x12%.reachy.sdk.joint.StreamJointsRequest\x1a\x1d.reachy.sdk.joint.JointsState0\x01\x12Y\n\x12SendJointsCommands\x12\x1f.reachy.sdk.joint.JointsCommand\x1a\".reachy.sdk.joint.JointsCommandAck\x12]\n\x14StreamJointsCommands\x12\x1f.reachy.sdk.joint.JointsCommand\x1a\".reachy.sdk.joint.JointsCommandAck(\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_JOINTFIELD = _descriptor.EnumDescriptor(
  name='JointField',
  full_name='reachy.sdk.joint.JointField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESENT_POSITION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESENT_SPEED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESENT_LOAD', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEMPERATURE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLIANT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOAL_POSITION', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED_LIMIT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TORQUE_LIMIT', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PID', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=12, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1972,
  serialized_end=2176,
)
_sym_db.RegisterEnumDescriptor(_JOINTFIELD)

JointField = enum_type_wrapper.EnumTypeWrapper(_JOINTFIELD)
NONE = 0
NAME = 1
UID = 2
PRESENT_POSITION = 3
PRESENT_SPEED = 4
PRESENT_LOAD = 5
TEMPERATURE = 6
COMPLIANT = 7
GOAL_POSITION = 8
SPEED_LIMIT = 9
TORQUE_LIMIT = 10
PID = 11
ALL = 15



_PIDGAINS = _descriptor.Descriptor(
  name='PIDGains',
  full_name='reachy.sdk.joint.PIDGains',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='p', full_name='reachy.sdk.joint.PIDGains.p', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i', full_name='reachy.sdk.joint.PIDGains.i', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='reachy.sdk.joint.PIDGains.d', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=170,
)


_COMPLIANCEMARGINSLOPE = _descriptor.Descriptor(
  name='ComplianceMarginSlope',
  full_name='reachy.sdk.joint.ComplianceMarginSlope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cw_compliance_margin', full_name='reachy.sdk.joint.ComplianceMarginSlope.cw_compliance_margin', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ccw_compliance_margin', full_name='reachy.sdk.joint.ComplianceMarginSlope.ccw_compliance_margin', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cw_compliance_slope', full_name='reachy.sdk.joint.ComplianceMarginSlope.cw_compliance_slope', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ccw_compliance_slope', full_name='reachy.sdk.joint.ComplianceMarginSlope.ccw_compliance_slope', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=316,
)


_PIDVALUE = _descriptor.Descriptor(
  name='PIDValue',
  full_name='reachy.sdk.joint.PIDValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='reachy.sdk.joint.PIDValue.pid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compliance', full_name='reachy.sdk.joint.PIDValue.compliance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='gains', full_name='reachy.sdk.joint.PIDValue.gains',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=318,
  serialized_end=443,
)


_JOINTID = _descriptor.Descriptor(
  name='JointId',
  full_name='reachy.sdk.joint.JointId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='reachy.sdk.joint.JointId.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='reachy.sdk.joint.JointId.uid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='reachy.sdk.joint.JointId.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=445,
  serialized_end=491,
)


_JOINTSTATE = _descriptor.Descriptor(
  name='JointState',
  full_name='reachy.sdk.joint.JointState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='reachy.sdk.joint.JointState.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='reachy.sdk.joint.JointState.uid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present_position', full_name='reachy.sdk.joint.JointState.present_position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present_speed', full_name='reachy.sdk.joint.JointState.present_speed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present_load', full_name='reachy.sdk.joint.JointState.present_load', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='reachy.sdk.joint.JointState.temperature', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compliant', full_name='reachy.sdk.joint.JointState.compliant', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_position', full_name='reachy.sdk.joint.JointState.goal_position', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='reachy.sdk.joint.JointState.speed_limit', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_limit', full_name='reachy.sdk.joint.JointState.torque_limit', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='reachy.sdk.joint.JointState.pid', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=1012,
)


_JOINTSSTATE = _descriptor.Descriptor(
  name='JointsState',
  full_name='reachy.sdk.joint.JointsState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.joint.JointsState.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='reachy.sdk.joint.JointsState.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.JointsState.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1161,
)


_JOINTSID = _descriptor.Descriptor(
  name='JointsId',
  full_name='reachy.sdk.joint.JointsId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='reachy.sdk.joint.JointsId.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uids', full_name='reachy.sdk.joint.JointsId.uids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1202,
)


_JOINTSSTATEREQUEST = _descriptor.Descriptor(
  name='JointsStateRequest',
  full_name='reachy.sdk.joint.JointsStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.joint.JointsStateRequest.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_fields', full_name='reachy.sdk.joint.JointsStateRequest.requested_fields', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.JointsStateRequest.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1368,
)


_STREAMJOINTSREQUEST = _descriptor.Descriptor(
  name='StreamJointsRequest',
  full_name='reachy.sdk.joint.StreamJointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='reachy.sdk.joint.StreamJointsRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publish_frequency', full_name='reachy.sdk.joint.StreamJointsRequest.publish_frequency', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.StreamJointsRequest.timestamp', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1521,
)


_JOINTCOMMAND = _descriptor.Descriptor(
  name='JointCommand',
  full_name='reachy.sdk.joint.JointCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='reachy.sdk.joint.JointCommand.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compliant', full_name='reachy.sdk.joint.JointCommand.compliant', index=1,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_position', full_name='reachy.sdk.joint.JointCommand.goal_position', index=2,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='reachy.sdk.joint.JointCommand.speed_limit', index=3,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque_limit', full_name='reachy.sdk.joint.JointCommand.torque_limit', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='reachy.sdk.joint.JointCommand.pid', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1524,
  serialized_end=1818,
)


_JOINTSCOMMAND = _descriptor.Descriptor(
  name='JointsCommand',
  full_name='reachy.sdk.joint.JointsCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='reachy.sdk.joint.JointsCommand.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='reachy.sdk.joint.JointsCommand.timestamp', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=1932,
)


_JOINTSCOMMANDACK = _descriptor.Descriptor(
  name='JointsCommandAck',
  full_name='reachy.sdk.joint.JointsCommandAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.joint.JointsCommandAck.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1934,
  serialized_end=1969,
)

_PIDVALUE.fields_by_name['pid'].message_type = _PIDGAINS
_PIDVALUE.fields_by_name['compliance'].message_type = _COMPLIANCEMARGINSLOPE
_PIDVALUE.oneofs_by_name['gains'].fields.append(
  _PIDVALUE.fields_by_name['pid'])
_PIDVALUE.fields_by_name['pid'].containing_oneof = _PIDVALUE.oneofs_by_name['gains']
_PIDVALUE.oneofs_by_name['gains'].fields.append(
  _PIDVALUE.fields_by_name['compliance'])
_PIDVALUE.fields_by_name['compliance'].containing_oneof = _PIDVALUE.oneofs_by_name['gains']
_JOINTID.oneofs_by_name['id'].fields.append(
  _JOINTID.fields_by_name['name'])
_JOINTID.fields_by_name['name'].containing_oneof = _JOINTID.oneofs_by_name['id']
_JOINTID.oneofs_by_name['id'].fields.append(
  _JOINTID.fields_by_name['uid'])
_JOINTID.fields_by_name['uid'].containing_oneof = _JOINTID.oneofs_by_name['id']
_JOINTSTATE.fields_by_name['uid'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_JOINTSTATE.fields_by_name['present_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['present_speed'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['present_load'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['temperature'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['compliant'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_JOINTSTATE.fields_by_name['goal_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['speed_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['torque_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTSTATE.fields_by_name['pid'].message_type = _PIDVALUE
_JOINTSSTATE.fields_by_name['ids'].message_type = _JOINTID
_JOINTSSTATE.fields_by_name['states'].message_type = _JOINTSTATE
_JOINTSSTATE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOINTSSTATEREQUEST.fields_by_name['ids'].message_type = _JOINTID
_JOINTSSTATEREQUEST.fields_by_name['requested_fields'].enum_type = _JOINTFIELD
_JOINTSSTATEREQUEST.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMJOINTSREQUEST.fields_by_name['request'].message_type = _JOINTSSTATEREQUEST
_STREAMJOINTSREQUEST.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOINTCOMMAND.fields_by_name['id'].message_type = _JOINTID
_JOINTCOMMAND.fields_by_name['compliant'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_JOINTCOMMAND.fields_by_name['goal_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTCOMMAND.fields_by_name['speed_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTCOMMAND.fields_by_name['torque_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_JOINTCOMMAND.fields_by_name['pid'].message_type = _PIDVALUE
_JOINTSCOMMAND.fields_by_name['commands'].message_type = _JOINTCOMMAND
_JOINTSCOMMAND.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['PIDGains'] = _PIDGAINS
DESCRIPTOR.message_types_by_name['ComplianceMarginSlope'] = _COMPLIANCEMARGINSLOPE
DESCRIPTOR.message_types_by_name['PIDValue'] = _PIDVALUE
DESCRIPTOR.message_types_by_name['JointId'] = _JOINTID
DESCRIPTOR.message_types_by_name['JointState'] = _JOINTSTATE
DESCRIPTOR.message_types_by_name['JointsState'] = _JOINTSSTATE
DESCRIPTOR.message_types_by_name['JointsId'] = _JOINTSID
DESCRIPTOR.message_types_by_name['JointsStateRequest'] = _JOINTSSTATEREQUEST
DESCRIPTOR.message_types_by_name['StreamJointsRequest'] = _STREAMJOINTSREQUEST
DESCRIPTOR.message_types_by_name['JointCommand'] = _JOINTCOMMAND
DESCRIPTOR.message_types_by_name['JointsCommand'] = _JOINTSCOMMAND
DESCRIPTOR.message_types_by_name['JointsCommandAck'] = _JOINTSCOMMANDACK
DESCRIPTOR.enum_types_by_name['JointField'] = _JOINTFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PIDGains = _reflection.GeneratedProtocolMessageType('PIDGains', (_message.Message,), {
  'DESCRIPTOR' : _PIDGAINS,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.PIDGains)
  })
_sym_db.RegisterMessage(PIDGains)

ComplianceMarginSlope = _reflection.GeneratedProtocolMessageType('ComplianceMarginSlope', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEMARGINSLOPE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ComplianceMarginSlope)
  })
_sym_db.RegisterMessage(ComplianceMarginSlope)

PIDValue = _reflection.GeneratedProtocolMessageType('PIDValue', (_message.Message,), {
  'DESCRIPTOR' : _PIDVALUE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.PIDValue)
  })
_sym_db.RegisterMessage(PIDValue)

JointId = _reflection.GeneratedProtocolMessageType('JointId', (_message.Message,), {
  'DESCRIPTOR' : _JOINTID,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointId)
  })
_sym_db.RegisterMessage(JointId)

JointState = _reflection.GeneratedProtocolMessageType('JointState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSTATE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointState)
  })
_sym_db.RegisterMessage(JointState)

JointsState = _reflection.GeneratedProtocolMessageType('JointsState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSSTATE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsState)
  })
_sym_db.RegisterMessage(JointsState)

JointsId = _reflection.GeneratedProtocolMessageType('JointsId', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSID,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsId)
  })
_sym_db.RegisterMessage(JointsId)

JointsStateRequest = _reflection.GeneratedProtocolMessageType('JointsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSSTATEREQUEST,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsStateRequest)
  })
_sym_db.RegisterMessage(JointsStateRequest)

StreamJointsRequest = _reflection.GeneratedProtocolMessageType('StreamJointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMJOINTSREQUEST,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamJointsRequest)
  })
_sym_db.RegisterMessage(StreamJointsRequest)

JointCommand = _reflection.GeneratedProtocolMessageType('JointCommand', (_message.Message,), {
  'DESCRIPTOR' : _JOINTCOMMAND,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointCommand)
  })
_sym_db.RegisterMessage(JointCommand)

JointsCommand = _reflection.GeneratedProtocolMessageType('JointsCommand', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSCOMMAND,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsCommand)
  })
_sym_db.RegisterMessage(JointsCommand)

JointsCommandAck = _reflection.GeneratedProtocolMessageType('JointsCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSCOMMANDACK,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsCommandAck)
  })
_sym_db.RegisterMessage(JointsCommandAck)



_JOINTSERVICE = _descriptor.ServiceDescriptor(
  name='JointService',
  full_name='reachy.sdk.joint.JointService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2179,
  serialized_end=2629,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAllJointsId',
    full_name='reachy.sdk.joint.JointService.GetAllJointsId',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_JOINTSID,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJointsState',
    full_name='reachy.sdk.joint.JointService.GetJointsState',
    index=1,
    containing_service=None,
    input_type=_JOINTSSTATEREQUEST,
    output_type=_JOINTSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamJointsState',
    full_name='reachy.sdk.joint.JointService.StreamJointsState',
    index=2,
    containing_service=None,
    input_type=_STREAMJOINTSREQUEST,
    output_type=_JOINTSSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendJointsCommands',
    full_name='reachy.sdk.joint.JointService.SendJointsCommands',
    index=3,
    containing_service=None,
    input_type=_JOINTSCOMMAND,
    output_type=_JOINTSCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamJointsCommands',
    full_name='reachy.sdk.joint.JointService.StreamJointsCommands',
    index=4,
    containing_service=None,
    input_type=_JOINTSCOMMAND,
    output_type=_JOINTSCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOINTSERVICE)

DESCRIPTOR.services_by_name['JointService'] = _JOINTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='trajectory.proto',
  package='reachy.sdk.trajectory',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10trajectory.proto\x12\x15reachy.sdk.trajectory\x1a\x1egoogle/protobuf/wrappers.proto\"\xd9\x01\n\x11TrajectoryRequest\x12\x36\n\x11starting_position\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x34\n\x0ftarget_position\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x02\x64t\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"+\n\nTrajectory\x12\x11\n\tpositions\x18\x01 \x03(\x01\x12\n\n\x02\x64t\x18\x02 \x01(\x01\x32\x80\x01\n\x11TrajectoryService\x12k\n\x1c\x43omputeMinimumJerkTrajectory\x12(.reachy.sdk.trajectory.TrajectoryRequest\x1a!.reachy.sdk.trajectory.Trajectoryb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_TRAJECTORYREQUEST = _descriptor.Descriptor(
  name='TrajectoryRequest',
  full_name='reachy.sdk.trajectory.TrajectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='starting_position', full_name='reachy.sdk.trajectory.TrajectoryRequest.starting_position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_position', full_name='reachy.sdk.trajectory.TrajectoryRequest.target_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='reachy.sdk.trajectory.TrajectoryRequest.duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dt', full_name='reachy.sdk.trajectory.TrajectoryRequest.dt', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=293,
)


_TRAJECTORY = _descriptor.Descriptor(
  name='Trajectory',
  full_name='reachy.sdk.trajectory.Trajectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='positions', full_name='reachy.sdk.trajectory.Trajectory.positions', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dt', full_name='reachy.sdk.trajectory.Trajectory.dt', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=338,
)

_TRAJECTORYREQUEST.fields_by_name['starting_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TRAJECTORYREQUEST.fields_by_name['target_position'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TRAJECTORYREQUEST.fields_by_name['duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TRAJECTORYREQUEST.fields_by_name['dt'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
DESCRIPTOR.message_types_by_name['TrajectoryRequest'] = _TRAJECTORYREQUEST
DESCRIPTOR.message_types_by_name['Trajectory'] = _TRAJECTORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrajectoryRequest = _reflection.GeneratedProtocolMessageType('TrajectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYREQUEST,
  '__module__' : 'trajectory_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.trajectory.TrajectoryRequest)
  })
_sym_db.RegisterMessage(TrajectoryRequest)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'trajectory_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.trajectory.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)



_TRAJECTORYSERVICE = _descriptor.ServiceDescriptor(
  name='TrajectoryService',
  full_name='reachy.sdk.trajectory.TrajectoryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=341,
  serialized_end=469,
  methods=[
  _descriptor.MethodDescriptor(
    name='ComputeMinimumJerkTrajectory',
    full_name='reachy.sdk.trajectory.TrajectoryService.ComputeMinimumJerkTrajectory',
    index=0,
    containing_service=None,
    input_type=_TRAJECTORYREQUEST,
    output_type=_TRAJECTORY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRAJECTORYSERVICE)

DESCRIPTOR.services_by_name['TrajectoryService'] = _TRAJECTORYSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import kinematics_pb2 as kinematics__pb2
import orbita_kinematics_pb2 as orbita__kinematics__pb2


class OrbitaKinematicsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ComputeOrbitaIK = channel.unary_unary(
                '/reachy.sdk.kinematics.OrbitaKinematics/ComputeOrbitaIK',
                request_serializer=orbita__kinematics__pb2.OrbitaIKRequest.SerializeToString,
                response_deserializer=orbita__kinematics__pb2.OrbitaIKSolution.FromString,
                )
        self.GetQuaternionTransform = channel.unary_unary(
                '/reachy.sdk.kinematics.OrbitaKinematics/GetQuaternionTransform',
                request_serializer=orbita__kinematics__pb2.LookVector.SerializeToString,
                response_deserializer=kinematics__pb2.Quaternion.FromString,
                )


class OrbitaKinematicsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ComputeOrbitaIK(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQuaternionTransform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrbitaKinematicsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ComputeOrbitaIK': grpc.unary_unary_rpc_method_handler(
                    servicer.ComputeOrbitaIK,
                    request_deserializer=orbita__kinematics__pb2.OrbitaIKRequest.FromString,
                    response_serializer=orbita__kinematics__pb2.OrbitaIKSolution.SerializeToString,
            ),
            'GetQuaternionTransform': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQuaternionTransform,
                    request_deserializer=orbita__kinematics__pb2.LookVector.FromString,
                    response_serializer=kinematics__pb2.Quaternion.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.kinematics.OrbitaKinematics', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrbitaKinematics(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ComputeOrbitaIK(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.kinematics.OrbitaKinematics/ComputeOrbitaIK',
            orbita__kinematics__pb2.OrbitaIKRequest.SerializeToString,
            orbita__kinematics__pb2.OrbitaIKSolution.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetQuaternionTransform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.kinematics.OrbitaKinematics/GetQuaternionTransform',
            orbita__kinematics__pb2.LookVector.SerializeToString,
            kinematics__pb2.Quaternion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zoom_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zoom_command.proto',
  package='reachy.sdk.zoom',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12zoom_command.proto\x12\x0freachy.sdk.zoom\x1a\x1bgoogle/protobuf/empty.proto\"\x1a\n\tZoomSpeed\x12\r\n\x05speed\x18\x01 \x01(\r\",\n\x0bZoomCommand\x12\x0c\n\x04side\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\".\n\x05\x45mpty\x12%\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty2\xa4\x01\n\x15ZoomControllerService\x12\x42\n\x0cSetZoomSpeed\x12\x1a.reachy.sdk.zoom.ZoomSpeed\x1a\x16.reachy.sdk.zoom.Empty\x12G\n\x0fSendZoomCommand\x12\x1c.reachy.sdk.zoom.ZoomCommand\x1a\x16.reachy.sdk.zoom.Emptyb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_ZOOMSPEED = _descriptor.Descriptor(
  name='ZoomSpeed',
  full_name='reachy.sdk.zoom.ZoomSpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='reachy.sdk.zoom.ZoomSpeed.speed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=94,
)


_ZOOMCOMMAND = _descriptor.Descriptor(
  name='ZoomCommand',
  full_name='reachy.sdk.zoom.ZoomCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='side', full_name='reachy.sdk.zoom.ZoomCommand.side', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='reachy.sdk.zoom.ZoomCommand.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=140,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='reachy.sdk.zoom.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='empty', full_name='reachy.sdk.zoom.Empty.empty', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=188,
)

_EMPTY.fields_by_name['empty'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
DESCRIPTOR.message_types_by_name['ZoomSpeed'] = _ZOOMSPEED
DESCRIPTOR.message_types_by_name['ZoomCommand'] = _ZOOMCOMMAND
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ZoomSpeed = _reflection.GeneratedProtocolMessageType('ZoomSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMSPEED,
  '__module__' : 'zoom_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.zoom.ZoomSpeed)
  })
_sym_db.RegisterMessage(ZoomSpeed)

ZoomCommand = _reflection.GeneratedProtocolMessageType('ZoomCommand', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMAND,
  '__module__' : 'zoom_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.zoom.ZoomCommand)
  })
_sym_db.RegisterMessage(ZoomCommand)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'zoom_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.zoom.Empty)
  })
_sym_db.RegisterMessage(Empty)



_ZOOMCONTROLLERSERVICE = _descriptor.ServiceDescriptor(
  name='ZoomControllerService',
  full_name='reachy.sdk.zoom.ZoomControllerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=191,
  serialized_end=355,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetZoomSpeed',
    full_name='reachy.sdk.zoom.ZoomControllerService.SetZoomSpeed',
    index=0,
    containing_service=None,
    input_type=_ZOOMSPEED,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendZoomCommand',
    full_name='reachy.sdk.zoom.ZoomControllerService.SendZoomCommand',
    index=1,
    containing_service=None,
    input_type=_ZOOMCOMMAND,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ZOOMCONTROLLERSERVICE)

DESCRIPTOR.services_by_name['ZoomControllerService'] = _ZOOMCONTROLLERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_reachy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='camera_reachy.proto',
  package='reachy.sdk.camera',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x63\x61mera_reachy.proto\x12\x11reachy.sdk.camera\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x15\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"1\n\x06\x43\x61mera\x12\'\n\x02id\x18\x01 \x01(\x0e\x32\x1b.reachy.sdk.camera.CameraId\"3\n\x07\x43\x61meras\x12(\n\x03ids\x18\x01 \x03(\x0e\x32\x1b.reachy.sdk.camera.CameraId\"9\n\x0cImageRequest\x12)\n\x06\x63\x61mera\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.camera.Camera\"F\n\x12StreamImageRequest\x12\x30\n\x07request\x18\x01 \x01(\x0b\x32\x1f.reachy.sdk.camera.ImageRequest\"\x1a\n\tZoomSpeed\x12\r\n\x05speed\x18\x01 \x01(\r\"\x0c\n\nZoomHoming\"E\n\tZoomLevel\x12\x38\n\x05level\x18\x01 \x01(\x0e\x32).reachy.sdk.camera.ZoomLevelPossibilities\"!\n\x0eZoomCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\xea\x01\n\x0bZoomCommand\x12)\n\x06\x63\x61mera\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.camera.Camera\x12\x37\n\x0ehoming_command\x18\x02 \x01(\x0b\x32\x1d.reachy.sdk.camera.ZoomHomingH\x00\x12\x35\n\rspeed_command\x18\x03 \x01(\x0b\x32\x1c.reachy.sdk.camera.ZoomSpeedH\x00\x12\x35\n\rlevel_command\x18\x04 \x01(\x0b\x32\x1c.reachy.sdk.camera.ZoomLevelH\x00\x42\t\n\x07\x63ommand\"\xda\x01\n\x10ZoomFocusMessage\x12\x30\n\nleft_focus\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\tleft_zoom\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bright_focus\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x30\n\nright_zoom\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value*\x1f\n\x08\x43\x61meraId\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01*>\n\x16ZoomLevelPossibilities\x12\x08\n\x04ZERO\x10\x00\x12\x06\n\x02IN\x10\x01\x12\t\n\x05INTER\x10\x02\x12\x07\n\x03OUT\x10\x03\x32\xd4\x05\n\rCameraService\x12\x45\n\x08GetImage\x12\x1f.reachy.sdk.camera.ImageRequest\x1a\x18.reachy.sdk.camera.Image\x12P\n\x0bStreamImage\x12%.reachy.sdk.camera.StreamImageRequest\x1a\x18.reachy.sdk.camera.Image0\x01\x12G\n\x0cGetZoomLevel\x12\x19.reachy.sdk.camera.Camera\x1a\x1c.reachy.sdk.camera.ZoomLevel\x12G\n\x0cGetZoomSpeed\x12\x19.reachy.sdk.camera.Camera\x1a\x1c.reachy.sdk.camera.ZoomSpeed\x12T\n\x0fSendZoomCommand\x12\x1e.reachy.sdk.camera.ZoomCommand\x1a!.reachy.sdk.camera.ZoomCommandAck\x12K\n\x0cGetZoomFocus\x12\x16.google.protobuf.Empty\x1a#.reachy.sdk.camera.ZoomFocusMessage\x12V\n\x0cSetZoomFocus\x12#.reachy.sdk.camera.ZoomFocusMessage\x1a!.reachy.sdk.camera.ZoomCommandAck\x12N\n\x0eStartAutofocus\x12\x19.reachy.sdk.camera.Camera\x1a!.reachy.sdk.camera.ZoomCommandAck\x12M\n\rStopAutofocus\x12\x19.reachy.sdk.camera.Camera\x1a!.reachy.sdk.camera.ZoomCommandAckb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_CAMERAID = _descriptor.EnumDescriptor(
  name='CameraId',
  full_name='reachy.sdk.camera.CameraId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=967,
  serialized_end=998,
)
_sym_db.RegisterEnumDescriptor(_CAMERAID)

CameraId = enum_type_wrapper.EnumTypeWrapper(_CAMERAID)
_ZOOMLEVELPOSSIBILITIES = _descriptor.EnumDescriptor(
  name='ZoomLevelPossibilities',
  full_name='reachy.sdk.camera.ZoomLevelPossibilities',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZERO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1000,
  serialized_end=1062,
)
_sym_db.RegisterEnumDescriptor(_ZOOMLEVELPOSSIBILITIES)

ZoomLevelPossibilities = enum_type_wrapper.EnumTypeWrapper(_ZOOMLEVELPOSSIBILITIES)
LEFT = 0
RIGHT = 1
ZERO = 0
IN = 1
INTER = 2
OUT = 3



_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='reachy.sdk.camera.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='reachy.sdk.camera.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=124,
)


_CAMERA = _descriptor.Descriptor(
  name='Camera',
  full_name='reachy.sdk.camera.Camera',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='reachy.sdk.camera.Camera.id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=175,
)


_CAMERAS = _descriptor.Descriptor(
  name='Cameras',
  full_name='reachy.sdk.camera.Cameras',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='reachy.sdk.camera.Cameras.ids', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=228,
)


_IMAGEREQUEST = _descriptor.Descriptor(
  name='ImageRequest',
  full_name='reachy.sdk.camera.ImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera', full_name='reachy.sdk.camera.ImageRequest.camera', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=287,
)


_STREAMIMAGEREQUEST = _descriptor.Descriptor(
  name='StreamImageRequest',
  full_name='reachy.sdk.camera.StreamImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='reachy.sdk.camera.StreamImageRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=359,
)


_ZOOMSPEED = _descriptor.Descriptor(
  name='ZoomSpeed',
  full_name='reachy.sdk.camera.ZoomSpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='reachy.sdk.camera.ZoomSpeed.speed', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=387,
)


_ZOOMHOMING = _descriptor.Descriptor(
  name='ZoomHoming',
  full_name='reachy.sdk.camera.ZoomHoming',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=401,
)


_ZOOMLEVEL = _descriptor.Descriptor(
  name='ZoomLevel',
  full_name='reachy.sdk.camera.ZoomLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='reachy.sdk.camera.ZoomLevel.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=472,
)


_ZOOMCOMMANDACK = _descriptor.Descriptor(
  name='ZoomCommandAck',
  full_name='reachy.sdk.camera.ZoomCommandAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='reachy.sdk.camera.ZoomCommandAck.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=507,
)


_ZOOMCOMMAND = _descriptor.Descriptor(
  name='ZoomCommand',
  full_name='reachy.sdk.camera.ZoomCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera', full_name='reachy.sdk.camera.ZoomCommand.camera', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='homing_command', full_name='reachy.sdk.camera.ZoomCommand.homing_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_command', full_name='reachy.sdk.camera.ZoomCommand.speed_command', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level_command', full_name='reachy.sdk.camera.ZoomCommand.level_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='reachy.sdk.camera.ZoomCommand.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=510,
  serialized_end=744,
)


_ZOOMFOCUSMESSAGE = _descriptor.Descriptor(
  name='ZoomFocusMessage',
  full_name='reachy.sdk.camera.ZoomFocusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_focus', full_name='reachy.sdk.camera.ZoomFocusMessage.left_focus', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_zoom', full_name='reachy.sdk.camera.ZoomFocusMessage.left_zoom', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_focus', full_name='reachy.sdk.camera.ZoomFocusMessage.right_focus', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_zoom', full_name='reachy.sdk.camera.ZoomFocusMessage.right_zoom', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=965,
)

_CAMERA.fields_by_name['id'].enum_type = _CAMERAID
_CAMERAS.fields_by_name['ids'].enum_type = _CAMERAID
_IMAGEREQUEST.fields_by_name['camera'].message_type = _CAMERA
_STREAMIMAGEREQUEST.fields_by_name['request'].message_type = _IMAGEREQUEST
_ZOOMLEVEL.fields_by_name['level'].enum_type = _ZOOMLEVELPOSSIBILITIES
_ZOOMCOMMAND.fields_by_name['camera'].message_type = _CAMERA
_ZOOMCOMMAND.fields_by_name['homing_command'].message_type = _ZOOMHOMING
_ZOOMCOMMAND.fields_by_name['speed_command'].message_type = _ZOOMSPEED
_ZOOMCOMMAND.fields_by_name['level_command'].message_type = _ZOOMLEVEL
_ZOOMCOMMAND.oneofs_by_name['command'].fields.append(
  _ZOOMCOMMAND.fields_by_name['homing_command'])
_ZOOMCOMMAND.fields_by_name['homing_command'].containing_oneof = _ZOOMCOMMAND.oneofs_by_name['command']
_ZOOMCOMMAND.oneofs_by_name['command'].fields.append(
  _ZOOMCOMMAND.fields_by_name['speed_command'])
_ZOOMCOMMAND.fields_by_name['speed_command'].containing_oneof = _ZOOMCOMMAND.oneofs_by_name['command']
_ZOOMCOMMAND.oneofs_by_name['command'].fields.append(
  _ZOOMCOMMAND.fields_by_name['level_command'])
_ZOOMCOMMAND.fields_by_name['level_command'].containing_oneof = _ZOOMCOMMAND.oneofs_by_name['command']
_ZOOMFOCUSMESSAGE.fields_by_name['left_focus'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_ZOOMFOCUSMESSAGE.fields_by_name['left_zoom'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_ZOOMFOCUSMESSAGE.fields_by_name['right_focus'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_ZOOMFOCUSMESSAGE.fields_by_name['right_zoom'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['Camera'] = _CAMERA
DESCRIPTOR.message_types_by_name['Cameras'] = _CAMERAS
DESCRIPTOR.message_types_by_name['ImageRequest'] = _IMAGEREQUEST
DESCRIPTOR.message_types_by_name['StreamImageRequest'] = _STREAMIMAGEREQUEST
DESCRIPTOR.message_types_by_name['ZoomSpeed'] = _ZOOMSPEED
DESCRIPTOR.message_types_by_name['ZoomHoming'] = _ZOOMHOMING
DESCRIPTOR.message_types_by_name['ZoomLevel'] = _ZOOMLEVEL
DESCRIPTOR.message_types_by_name['ZoomCommandAck'] = _ZOOMCOMMANDACK
DESCRIPTOR.message_types_by_name['ZoomCommand'] = _ZOOMCOMMAND
DESCRIPTOR.message_types_by_name['ZoomFocusMessage'] = _ZOOMFOCUSMESSAGE
DESCRIPTOR.enum_types_by_name['CameraId'] = _CAMERAID
DESCRIPTOR.enum_types_by_name['ZoomLevelPossibilities'] = _ZOOMLEVELPOSSIBILITIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Image)
  })
_sym_db.RegisterMessage(Image)

Camera = _reflection.GeneratedProtocolMessageType('Camera', (_message.Message,), {
  'DESCRIPTOR' : _CAMERA,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Camera)
  })
_sym_db.RegisterMessage(Camera)

Cameras = _reflection.GeneratedProtocolMessageType('Cameras', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAS,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Cameras)
  })
_sym_db.RegisterMessage(Cameras)

ImageRequest = _reflection.GeneratedProtocolMessageType('ImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEREQUEST,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ImageRequest)
  })
_sym_db.RegisterMessage(ImageRequest)

StreamImageRequest = _reflection.GeneratedProtocolMessageType('StreamImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMIMAGEREQUEST,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.StreamImageRequest)
  })
_sym_db.RegisterMessage(StreamImageRequest)

ZoomSpeed = _reflection.GeneratedProtocolMessageType('ZoomSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMSPEED,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomSpeed)
  })
_sym_db.RegisterMessage(ZoomSpeed)

ZoomHoming = _reflection.GeneratedProtocolMessageType('ZoomHoming', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMHOMING,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomHoming)
  })
_sym_db.RegisterMessage(ZoomHoming)

ZoomLevel = _reflection.GeneratedProtocolMessageType('ZoomLevel', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMLEVEL,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomLevel)
  })
_sym_db.RegisterMessage(ZoomLevel)

ZoomCommandAck = _reflection.GeneratedProtocolMessageType('ZoomCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMANDACK,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomCommandAck)
  })
_sym_db.RegisterMessage(ZoomCommandAck)

ZoomCommand = _reflection.GeneratedProtocolMessageType('ZoomCommand', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMAND,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomCommand)
  })
_sym_db.RegisterMessage(ZoomCommand)

ZoomFocusMessage = _reflection.GeneratedProtocolMessageType('ZoomFocusMessage', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMFOCUSMESSAGE,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomFocusMessage)
  })
_sym_db.RegisterMessage(ZoomFocusMessage)



_CAMERASERVICE = _descriptor.ServiceDescriptor(
  name='CameraService',
  full_name='reachy.sdk.camera.CameraService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1065,
  serialized_end=1789,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetImage',
    full_name='reachy.sdk.camera.CameraService.GetImage',
    index=0,
    containing_service=None,
    input_type=_IMAGEREQUEST,
    output_type=_IMAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamImage',
    full_name='reachy.sdk.camera.CameraService.StreamImage',
    index=1,
    containing_service=None,
    input_type=_STREAMIMAGEREQUEST,
    output_type=_IMAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetZoomLevel',
    full_name='reachy.sdk.camera.CameraService.GetZoomLevel',
    index=2,
    containing_service=None,
    input_type=_CAMERA,
    output_type=_ZOOMLEVEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetZoomSpeed',
    full_name='reachy.sdk.camera.CameraService.GetZoomSpeed',
    index=3,
    containing_service=None,
    input_type=_CAMERA,
    output_type=_ZOOMSPEED,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendZoomCommand',
    full_name='reachy.sdk.camera.CameraService.SendZoomCommand',
    index=4,
    containing_service=None,
    input_type=_ZOOMCOMMAND,
    output_type=_ZOOMCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetZoomFocus',
    full_name='reachy.sdk.camera.CameraService.GetZoomFocus',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_ZOOMFOCUSMESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetZoomFocus',
    full_name='reachy.sdk.camera.CameraService.SetZoomFocus',
    index=6,
    containing_service=None,
    input_type=_ZOOMFOCUSMESSAGE,
    output_type=_ZOOMCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartAutofocus',
    full_name='reachy.sdk.camera.CameraService.StartAutofocus',
    index=7,
    containing_service=None,
    input_type=_CAMERA,
    output_type=_ZOOMCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopAutofocus',
    full_name='reachy.sdk.camera.CameraService.StopAutofocus',
    index=8,
    containing_service=None,
    input_type=_CAMERA,
    output_type=_ZOOMCOMMANDACK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMERASERVICE)

DESCRIPTOR.services_by_name['CameraService'] = _CAMERASERVICE

# @@protoc_insertion_point(module_scope)
